<?php
namespace MascotCoreNovioElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

use MASCOTCORENOVIO\Lib;
use MASCOTCORENOVIO\CPT\Gallery\CPT_Gallery;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Gallery extends Widget_Base {

  /**
   * Retrieve the widget name.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'tm-ele-cpt-gallery';
  }

  /**
   * Retrieve the widget title.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return __( 'Gallery', 'mascot-core-elementor' );
  }

  /**
   * Retrieve the widget icon.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-posts-ticker';
  }

  /**
   * Retrieve the list of categories the widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * Note that currently Elementor supports only one category.
   * When multiple categories passed, Elementor uses the first one.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'tm' ];
  }

  /**
   * Retrieve the list of scripts the widget depended on.
   *
   * Used to set scripts dependencies required to run the widget.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget scripts dependencies.
   */
  public function get_script_depends() {
    return [ 'mascot-core-hellojs' ];
  }

  /**
   * Register the widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function register_controls() {
    $new_cpt_class = CPT_Gallery::Instance();
    $categories_array = novio_mascot_category_list_array( $new_cpt_class->ptTaxKey );
    $orderby_parameters_list = mascot_core_novio_orderby_parameters_list();

    $this->start_controls_section(
      'general',
      [
        'label' => esc_html__( 'General', 'mascot-core-elementor' ),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
    $this->add_control(
      'custom_css_class',
      [
        'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::TEXT,
      ]
    );
    $this->add_control(
      'design_style',
      [
        'label' => esc_html__( "Design Style", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
          'gallery-style1-current-theme' => esc_html__( 'Style 1 - Current Theme', 'mascot-core-elementor' ),
          'gallery-style2-simple' => esc_html__( 'Style 2 - Simple', 'mascot-core-elementor' ),
          'gallery-style3-classic' => esc_html__( 'Style 3 - Classic', 'mascot-core-elementor' ),
          'gallery-style4-modern' => esc_html__( 'Style 4 - Modern', 'mascot-core-elementor' ),
        ],
        'default' => 'gallery-style1-current-theme'
      ]
    );
    $this->add_control(
      'display_type',
      [
        'label' => esc_html__( "Display Type", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
          'grid'  =>  esc_html__( 'Grid', 'mascot-core-elementor' ),
          'masonry' =>  esc_html__( 'Masonry', 'mascot-core-elementor' ),
          'masonry-tiles' =>  esc_html__( 'Masonry Tiles', 'mascot-core-elementor' ),
          'carousel'  =>  esc_html__( 'Carousel', 'mascot-core-elementor' )
        ],
        'default' => 'grid'
      ]
    );
    $this->add_control(
      'columns',
      [
        'label' => esc_html__( "Columns Layout", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'description' => esc_html__( 'Define Columns Layout for Grid/Carousel', 'mascot-core-elementor' ),
        'options' => [
          '1'  =>  '1',
          '2'  =>  '2',
          '3'  =>  '3',
          '4'  =>  '4',
          '5'  =>  '5',
          '6'  =>  '6',
          '7'  =>  '7',
          '8'  =>  '8',
          '9'  =>  '9',
          '10'  =>  '10',
        ],
        'default' => '3'
      ]
    );
    $this->add_control(
      'featured_image_size', [
        'label' => esc_html__( "Featured Image Size", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_get_available_image_sizes(),
      ]
    );
    $this->add_control(
      'use_masonry_tiles_featured_image_size', [
        'label' => esc_html__( "Use Predefined Image Size in Masonry Mode", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        "description" => esc_html__( "You can select predefined image size from each items edit page. If you choose yes, then 'Featured Image Size' will not work", 'mascot-core-elementor' ),
        'default' => 'no',
        'condition' => [
          'display_type' => array('masonry', 'masonry-tiles')
        ]
      ]
    );

    $this->end_controls_section();





    //Carousel Options
    $this->start_controls_section(
      'carousel_options', [
        'label' => esc_html__( 'Carousel Options', 'mascot-core-elementor' ),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        'condition' => [
          'display_type' => array('carousel')
        ]
      ]
    );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 1, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 2, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 3, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 4, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 5, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 6, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 7, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 8, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 9, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 10, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 11, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 12, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 13, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 14, '', array('display_type' => array('carousel') ) );
    mascot_core_novio_elementor_get_owl_carousel_arraylist( $this, 15, '', array('display_type' => array('carousel') ) );

    $this->end_controls_section();







    //Query Options
    $this->start_controls_section(
      'query',
      [
        'label' => esc_html__( 'Query', 'mascot-core-elementor' ),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
    $this->add_control(
      'total_items',
      [
        'label' => esc_html__( "Number of Items to Query from Database", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::TEXT,
        "description" => esc_html__( "How many items do you wish to show? Put -1 to show all. Default 3", 'mascot-core-elementor' ),
        'default' => '3'
      ]
    );
    $this->add_control(
      'selected_category',
      [
        'label' => esc_html__( "Category", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => $categories_array,
      ]
    );
    $this->add_control(
      'order_by',
      [
        'label' => esc_html__( "Order By", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => $orderby_parameters_list,
      ]
    );
    $this->add_control(
      'order',
      [
        'label' => esc_html__( "Order", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'Descending' => esc_html__( 'DESC', 'mascot-core-elementor' ),
            'Ascending' => esc_html__( 'ASC', 'mascot-core-elementor' ),
        ],
      ]
    );

    $this->end_controls_section();







    //Category Filter
    $this->start_controls_section(
      'cat_filter_section', [
        'label' => esc_html__( 'Category Filter', 'mascot-core-elementor' ),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
    mascot_core_novio_elementor_get_cat_filter_arraylist( $this, 1, array('display_type' => array('grid', 'masonry', 'masonry-tiles', 'carousel') ) );
    mascot_core_novio_elementor_get_cat_filter_arraylist( $this, 2 );
    mascot_core_novio_elementor_get_cat_filter_arraylist( $this, 3 );
    mascot_core_novio_elementor_get_cat_filter_arraylist( $this, 4 );

    $this->end_controls_section();








    //Content Options
    $this->start_controls_section(
      'content',
      [
        'label' => esc_html__( 'Content', 'mascot-core-elementor' ),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
    $this->add_control(
      'gutter',
      [
        'label' => esc_html__( "Gutter", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_isotope_gutter_list(),
        'default' => 'gutter-15',
        'condition' => [
          'display_type' => array('grid')
        ]
      ]
    );
    $this->add_control(
      'gallery_overlay_color_on_image',
      [
        'label' => esc_html__( "Overlay Color on Image", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'shade-theme-colored1' => esc_html__( 'Theme Color 1 Ovedrlay', 'mascot-core-elementor' ),
            'shade-theme-colored2' => esc_html__( 'Theme Color 2 Ovedrlay', 'mascot-core-elementor' ),
            'shade-black' => esc_html__( 'Black Ovedrlay', 'mascot-core-elementor' ),
            'shade-white' => esc_html__( 'White Ovedrlay', 'mascot-core-elementor' ),
        ],
      ]
    );
    $this->add_control(
      'show_gradient_effect_on_image',
      [
        'label' => esc_html__( "Add Gradient Effect on Image", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'default' => 'yes'
      ]
    );
    $this->add_control(
      'show_gallery_title',
      [
        'label' => esc_html__( "Show Title", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'default' => 'yes'
      ]
    );
    $this->add_control(
      'title_tag',
      [
        'label' => esc_html__( "Name Tag", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_heading_tag_list(),
        'default' => 'h5',
        'condition' => [
          'show_gallery_title' => array('yes')
        ]
      ]
    );
    $this->add_control(
      'show_gallery_date',
      [
        'label' => esc_html__( "Show Date", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'default' => 'no'
      ]
    );
    $this->add_control(
      'show_selected_category',
      [
        'label' => esc_html__( "Show Category", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'default' => 'no'
      ]
    );
    $this->add_control(
      'show_gallery_description',
      [
        'label' => esc_html__( "Show Description", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'default' => 'no'
      ]
    );
    $this->end_controls_section();


    //lightbox Options
    $this->start_controls_section(
      'lightbox',
      [
        'label' => esc_html__( 'Lightbox', 'mascot-core-elementor' ),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
    $this->add_control(
      'lightbox_scroll_through',
      [
        'label' => esc_html__( "Lightbox Scroll Through", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
            'scroll-featured-images' => esc_html__( 'Scroll Through Only Featured Images', 'mascot-core-elementor' ),
            'scroll-gallery-images' => esc_html__( 'Scroll Through Own Gallery Images', 'mascot-core-elementor' ),
        ],
        'default' => 'scroll-featured-images'
      ]
    );
    $this->add_control(
      'show_link_icon_on_hover',
      [
        'label' => esc_html__( "Show Link(Details Page) Icon on Hover", 'mascot-core-elementor' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'default' => 'no'
      ]
    );

    $this->end_controls_section();






    $this->start_controls_section(
      'loadmore_button_options', [
          'label' => esc_html__( 'Loadmore Button Options', 'mascot-core-elementor' ),
          'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
    mascot_core_novio_elementor_get_viewdetails_button_arraylist($this, 1,  esc_html__( "Load More", 'mascot-core-elementor' ), 'loadmore_');
    mascot_core_novio_elementor_get_viewdetails_button_arraylist($this, 2,  esc_html__( "Load More", 'mascot-core-elementor' ), 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 1, 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 2, 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 3, 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 4, 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 5, 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 6, 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 7, 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 8, 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 9, 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 10, 'loadmore_');
    mascot_core_novio_elementor_get_button_arraylist($this, 11, 'loadmore_');

    $this->end_controls_section();


  }

  /**
   * Render the widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function render() {
    $settings = $this->get_settings_for_display();

    $new_cpt_class = CPT_Gallery::Instance();
    $new_cpt_class =  (array) $new_cpt_class;
    $paged = isset($settings['paged']) ? $settings['paged'] : '';

    
    //query args
    $args = array(
      'post_type' => $new_cpt_class['ptKey'],
      'orderby' => $settings['order_by'],
      'order' => $settings['order'],
      'posts_per_page' => $settings['total_items'],
      'paged' => $paged,
    );

    //if category selected
    if( ! empty( $settings['selected_category'] ) ) {
      $args['tax_query'] = array(
        array(
          'taxonomy' => $new_cpt_class['ptTaxKey'],
          'field' => 'slug',
          'terms' => explode(',', $settings['selected_category']),
        )
      );
    }

    $the_query = new \WP_Query( $args );
    $settings['the_query'] = $the_query;
    
    if ( !$the_query->have_posts() && isset( $settings['from_loadmore_ajax_handler'] ) && $settings['from_loadmore_ajax_handler'] === true ) {
      return;
    }
    
    //ptTaxKey
    $settings['ptTaxKey'] = $new_cpt_class['ptTaxKey'];
    
    //classes
    $classes = array();
    $classes[] = $settings['design_style'];
    if( $settings['display_type'] == 'carousel' ) {
      $classes[] = $settings['bullets_skin'];
      $classes[] = $settings['bullets_alignment'];
    }
    $classes[] = $settings['custom_css_class'];
    $settings['classes'] = $classes;

    
    $settings['loadmore_btn_classes'] = novio_mascot_prepare_button_classes_from_params( $settings, 'loadmore_' );
    
    //Owl Carousel Data
    $settings['owl_carousel_data_info'] = novio_mascot_prepare_owlcarousel_data_from_params( $settings );
    $settings['settings'] = $settings;

    novio_mascot_wp_enqueue_script_lightgallery();

    //Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
    $html = mascot_core_novio_elementor_get_cpt_shortcode_template_part( 'gallery', $settings['display_type'], 'gallery/tpl', $settings, true );
    
    echo $html;
  }
}
