<?php

if(!function_exists('mascot_core_novio_elementor_get_cpt_shortcode_template_part')) {
	/**
	 * Load a cpt shortcode template part into a template
	 *
	 * @param string $slug The slug name for the generic template.
	 * @param string $name The name of the specialised template.
	 * @param string $folder The name of the specialised folder.
	 * @param array $params array of parameters to pass to the template.
	 * @param boolean $shortcode_ob_start only for shortcodes to get HTML string.
	 */
	function mascot_core_novio_elementor_get_cpt_shortcode_template_part( $slug, $name = null, $folder = '', $params = array(), $shortcode_ob_start = false ) {

		$template_path = 'cpt/' . $folder . '/' . $slug;

		return mascot_core_novio_elementor_get_template_part( $template_path, $name, $params, $shortcode_ob_start );

	}
}

if(!function_exists('mascot_core_novio_elementor_get_shortcode_template_part')) {
	/**
	 * Load a shortcode template part into a template
	 *
	 * @param string $slug The slug name for the generic template.
	 * @param string $name The name of the specialised template.
	 * @param string $folder The name of the specialised folder.
	 * @param array $params array of parameters to pass to the template.
	 * @param boolean $shortcode_ob_start only for shortcodes to get HTML string.
	 */
	function mascot_core_novio_elementor_get_shortcode_template_part( $slug, $name = null, $folder = '', $params = array(), $shortcode_ob_start = false ) {

		$template_path = 'widgets/' . $folder . '/' . $slug;

		return mascot_core_novio_elementor_get_template_part( $template_path, $name, $params, $shortcode_ob_start );

	}
}


if(!function_exists('mascot_core_novio_elementor_get_template_part')) {
	/**
	 * Load a template part into a template
	 *
	 * @param string $template_path path of the specialised template.
	 * @param string $name The name of the specialised template.
	 * @param array $params array of parameters to pass to the template.
	 * @param boolean $shortcode_ob_start only for shortcodes to get HTML string.
	 */
	function mascot_core_novio_elementor_get_template_part( $template_path, $name = null, $params = array(), $shortcode_ob_start = false ) {

		$output_html = '';

		if( is_array($params) && count($params) ) {
			extract($params);
		}

		$templates = array();
		$name = (string) $name;
		if ( '' !== $name )
			$templates[] = "{$template_path}-{$name}.php";

		$templates[] = "{$template_path}.php";

		$located = mascot_core_novio_elementor_locate_template($templates);

		if($located) {
			if( $shortcode_ob_start ) {
				ob_start();
				include($located);
				$output_html = ob_get_clean();
			} else {
				include($located);
			}
		}

		return $output_html;
	}
}

if(!function_exists('mascot_core_novio_elementor_locate_template')) {
	/**
	 * Retrieve the name of the highest priority template file that exists.
	 *
	 * Searches in the MASCOT_STYLESHEET_DIR before MASCOT_TEMPLATE_DIR
	 * so that themes which inherit from a parent theme can just overload one file.
	 *
	 * @param string|array $template_names Template file(s) to search for, in order.
	 * @return string The template filename if one is located.
	 */
	function mascot_core_novio_elementor_locate_template($template_names) {
		$located = '';
		foreach ( (array) $template_names as $template_name ) {
			if ( !$template_name ) {
				continue;
			}
			if ( file_exists(MASCOT_CORE_NOVIO_ELEMENTOR_ABS_PATH . '/' . $template_name)) {
				$located = MASCOT_CORE_NOVIO_ELEMENTOR_ABS_PATH . '/' . $template_name;
				break;
			}
		}
		return $located;
	}
}


if ( ! function_exists('mascot_core_novio_elementor_get_yes_no_select_array') ) {
	/**
	 * Returns array of yes no
	 * @return array
	 */
	function mascot_core_novio_elementor_get_yes_no_select_array($enable_default = true, $set_yes_to_be_first = false ) {
		$select_options = array();

		if ( $enable_default ) {
			$select_options[''] = esc_html__( 'Default', 'mascot-core-elementor' );
		}

		if ( $set_yes_to_be_first ) {
			$select_options['yes'] = esc_html__( 'Yes', 'mascot-core-elementor' );
			$select_options['no']  = esc_html__( 'No', 'mascot-core-elementor' );
		} else {
			$select_options['no']  = esc_html__( 'No', 'mascot-core-elementor' );
			$select_options['yes'] = esc_html__( 'Yes', 'mascot-core-elementor' );
		}

		return $select_options;
	}
}
if( ! function_exists('mascot_core_novio_elementor_add_elementor_widget_categories') ) {
		function mascot_core_novio_elementor_add_elementor_widget_categories($elements_manager) {

				$elements_manager->add_category(
						'tm',
						[
								'title' => esc_html__('Mascot', 'mascot-core-elementor'),
								'icon' => 'fa fa-plug',
						]
				);

		}

		add_action('elementor/elements/categories_registered', 'mascot_core_novio_elementor_add_elementor_widget_categories');
};



if(!function_exists('mascot_core_novio_elementor_get_button_arraylist')) {
	/**
	 * Return Button Array List
	 */
	function mascot_core_novio_elementor_get_button_arraylist( $control_object, $serial, $prefix = '' ) {
		$array = array();

		switch ( $serial ) {
			case '1':
				$control_object->add_control(
						$prefix . "btn_design_style", [
								'label' => esc_html__( "Button Design Style", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::SELECT,
								'options' => mascot_core_novio_elementor_get_btn_design_style(),
								'default' => 'btn-theme-colored1',
						]
				);
				break;

			case '2':
				$control_object->add_control(
						$prefix . "button_size", [
								'label' => esc_html__( "Button Size", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::SELECT,
								'options' => mascot_core_novio_elementor_get_button_size(),
								'default' => '',
						]
				);
				break;

			case '3':
				$control_object->add_control(
						$prefix . "button_alignment", [
								'label' => esc_html__( "Button Alignment", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::SELECT,
								'options' => novio_mascot_redux_text_alignment_list(),
								'default' => '',
						]
				);
				break;

			case '4':
				$control_object->add_control(
						$prefix . "button_hover_animation_effect", [
								'label' => esc_html__( "Animation Effect", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::SELECT,
								'options' => array(
									''	=> 	esc_html__( 'None', 'mascot-core-elementor' ),
									'hvr-sweep-to-right'	=> 	esc_html__( 'Sweep To Right', 'mascot-core-elementor' ),
									'hvr-bounce-to-right'	=> 	esc_html__( 'Bounce To Right', 'mascot-core-elementor' ),
									'hvr-shutter-out-horizontal'	=> 	esc_html__( 'Shutter Out Horizontal', 'mascot-core-elementor' ),
									'btn-arrow-hover-animation'	=> 	esc_html__( 'Arrow Hover Animation', 'mascot-core-elementor' ),
								),
								'default' => '',
						]
				);
				break;

			case '5':
				$control_object->add_control(
						$prefix . "btn_class", [
								'label' => esc_html__( "Custom CSS Class", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::TEXT,
						]
				);
				break;

			case '6':
				$control_object->add_control(
						$prefix . "btn_outlined", [
								'label' => esc_html__( "Make Button Outlined", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::SWITCHER,
						]
				);
				break;

			case '7':
				$control_object->add_control(
						$prefix . "btn_round", [
								'label' => esc_html__( "Make Button Round", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::SWITCHER,
						]
				);
				break;

			case '8':
				$control_object->add_control(
						$prefix . "btn_flat", [
								'label' => esc_html__( "Make Button Flat", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::SWITCHER,
						]
				);
				break;

			case '9':
				$control_object->add_control(
						$prefix . "btn_block", [
								'label' => esc_html__( "Button Fullwidth (Block Level Button)", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::SWITCHER,
						]
				);
				break;

			case '10':
				$control_object->add_control(
						$prefix . "btn_threed_effect", [
								'label' => esc_html__( "3D Effect", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::SWITCHER,
						]
				);
				break;

			case '11':
				$control_object->add_control(
						$prefix . "btn_gradient_effect", [
								'label' => esc_html__( "Gradient Effect", 'mascot-core-elementor' ),
								'type' => \Elementor\Controls_Manager::SWITCHER,
								'default' => 'yes',
						]
				);
				break;

			default:
				# code...
				break;
		}

		return $array;
	}
}

if(!function_exists('mascot_core_novio_elementor_get_viewdetails_button_arraylist')) {
	/**
	 * Return Button Show Array List
	 */
	function mascot_core_novio_elementor_get_viewdetails_button_arraylist( $control_object, $serial, $btn_text = '', $prefix = '', $std = 'true' ) {
		$array = array();
		if( $btn_text == '' ) $btn_text = esc_html__( 'View Details', 'mascot-core-elementor' );

		switch ( $serial ) {
			case '1':
				$control_object->add_control(
						$prefix . "show_view_details_button", [
								'label' => sprintf( __( "Show %s Button", 'mascot-core-elementor' ), $btn_text ),
								'type' => \Elementor\Controls_Manager::SELECT,
								'options' => array(
										'no'  => esc_html__( 'No', 'mascot-core-elementor' ),
										'yes' => esc_html__( 'Yes', 'mascot-core-elementor' ),
								),
								'default' => 'no',
						]
				);
				break;

			case '2':
				$control_object->add_control(
						$prefix . "view_details_button_text", [
								'label' => sprintf( __( "%s Button Text", 'mascot-core-elementor' ), $btn_text ),
								'type' => \Elementor\Controls_Manager::TEXT,
								'default' => esc_html( $btn_text ),
						]
				);
				break;

			default:
				# code...
				break;
		}
	}
}

if(!function_exists('mascot_core_novio_elementor_font_style_list')) {
	/**
	 * Font Style List
	 */
	function mascot_core_novio_elementor_font_style_list() {
		$font_style_list = array(
			''	=>	esc_html__( 'Normal', 'mascot-core-elementor'),
			'italic'	=>	esc_html__( 'Italic', 'mascot-core-elementor')
		);
		return $font_style_list;
	}
}

if(!function_exists('mascot_core_novio_elementor_font_weight_list')) {
	/**
	 * Font weight List
	 */
	function mascot_core_novio_elementor_font_weight_list() {
		$font_weight_list = array(
			''			=>	esc_html__( 'Default', 'mascot-core-elementor'),
			'100'   => '100',
			'200'   => '200',
			'300'   => '300',
			'400'   => '400',
			'500'   => '500',
			'600'   => '600',
			'700'   => '700',
			'800'   => '800',
		);
		return $font_weight_list;
	}
}

if(!function_exists('mascot_core_novio_elementor_text_transform_list')) {
	/**
	 * Text Transform List
	 */
	function mascot_core_novio_elementor_text_transform_list() {
		$text_transform_list = array(
			''	=>	esc_html__( 'Default', 'mascot-core-elementor'),
			'none'	=>	esc_html__( 'None', 'mascot-core-elementor'),
			'capitalize'	=>	esc_html__( 'Capitalize', 'mascot-core-elementor'),
			'uppercase'	=>	esc_html__( 'Uppercase', 'mascot-core-elementor'),
			'lowercase'	=>	esc_html__( 'Lowercase', 'mascot-core-elementor'),
			'initial'	=>	esc_html__( 'Initial', 'mascot-core-elementor'),
			'inherit'	=>	esc_html__( 'Inherit', 'mascot-core-elementor')
		);
		return $text_transform_list;
	}
}

if(!function_exists('mascot_core_novio_elementor_get_btn_design_style')) {
	/**
	 * Return Design Style
	 */
	function mascot_core_novio_elementor_get_btn_design_style() {
		$array = array(
			'btn-primary'	=>	esc_html__( 'Button Primary', 'mascot-core-elementor'),
			'btn-secondary'	=>	esc_html__( 'Button Secondary', 'mascot-core-elementor'),
			'btn-success'	=>	esc_html__( 'Button Success', 'mascot-core-elementor'),
			'btn-danger'	=>	esc_html__( 'Button Danger', 'mascot-core-elementor'),
			'btn-warning'	=>	esc_html__( 'Button Warning', 'mascot-core-elementor'),
			'btn-info'	=>	esc_html__( 'Button Info', 'mascot-core-elementor'),
			'btn-light'	=>	esc_html__( 'Button Light', 'mascot-core-elementor'),
			'btn-dark'	=>	esc_html__( 'Button Dark', 'mascot-core-elementor'),
			'btn-gray'	=>	esc_html__( 'Button Gray', 'mascot-core-elementor'),
			'btn-plain-text'	=>	esc_html__( 'Plain Text', 'mascot-core-elementor'),
			'btn-plain-text-with-arrow'	=>	esc_html__( 'Plain Text + Arrow', 'mascot-core-elementor'),
			'btn-modern-white'	=>	esc_html__( 'Button Modern White', 'mascot-core-elementor'),
			'btn-modern-theme-colored'	=>	esc_html__( 'Button Modern Theme Colored', 'mascot-core-elementor')
		);

		$array_theme_color = array();
		for ($i=1; $i <= novio_mascot_number_of_theme_colors(); $i++) {
			$array_theme_color[ 'btn-theme-colored' . $i ] = esc_html__( 'Button Theme Colored', 'mascot-core-elementor') . ' ' . $i;
		}

		$array = array_merge($array, $array_theme_color);
		return $array;
	}
}

if(!function_exists('mascot_core_novio_elementor_get_button_size')) {
	/**
	 * Return Button Size
	 */
	function mascot_core_novio_elementor_get_button_size() {
		$array = array(
			''	=>	esc_html__( 'Default', 'mascot-core-elementor'),
			'btn-lg'	=>	esc_html__( 'Large', 'mascot-core-elementor'),
			'btn-sm'	=>	esc_html__( 'Small', 'mascot-core-elementor'),
			'btn-xs'	=>	esc_html__( 'Extra Small', 'mascot-core-elementor')
		);
		return $array;
	}
}


if ( ! function_exists( 'mascot_core_novio_elementor_get_available_image_sizes' ) ) {
	/**
	 * Get information about available image sizes
	 */
	function mascot_core_novio_elementor_get_available_image_sizes() {
		$size = array();
		$available_image_sizes = novio_mascot_get_available_image_sizes();

		// Create the full array with sizes and crop info
		foreach( $available_image_sizes as $key => $value ) {
			$sizes[ $key ]	=	$key . ( ($value['crop'] == 1) ? ' - cropped' : '') . ' - (' .$value['width'] . 'x' . $value['height'] . ')';
		}
		return $sizes;
	}
}




if(!function_exists('mascot_core_novio_elementor_get_owl_carousel_arraylist')) {
	/**
	 * Return Owl Carousel Array List
	 */
	function mascot_core_novio_elementor_get_owl_carousel_arraylist( $control_object, $serial, $prefix = '', $dependency = array() ) {
		$array = array();

		switch ( $serial ) {
			case '1':
				$control_object->add_control(
					$prefix . "show_navigation", [
						'label' => esc_html__( "Show Arrow Navigation", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SWITCHER,
						'default' => 'yes',
						'condition' => $dependency
					]
				);
				break;

			case '2':
				$control_object->add_control(
					$prefix . "show_bullets",[
						'label' => esc_html__( "Show Bullets/Dots Navigation", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SWITCHER,
						'default' => 'no',
						'condition' => $dependency
					]
				);
				break;

			case '3':
				$control_object->add_control(
					$prefix . "bullets_skin", [
						'label' => esc_html__( "Bullets/Dots Skin", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'options' => array(
							'owl-dots-light-skin'	=>	esc_html__( 'Light Bullets', 'mascot-core-elementor' ),
							'owl-dots-dark-skin'	=>	esc_html__( 'Dark Bullets', 'mascot-core-elementor' )
						),
						'default' => '',
						'condition' => [
							'display_type' => array('carousel')
						]
					]
				);
				break;

			case '4':
				$control_object->add_control(
					$prefix . "bullets_alignment", [
						'label' => esc_html__( "Bullets/Dots Alignment", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'options' => array(
							'owl-dots-center'	=>	esc_html__( 'Center', 'mascot-core-elementor' ),
							'owl-dots-left'	=>	esc_html__( 'Left', 'mascot-core-elementor' ),
							'owl-dots-right'	=>	esc_html__( 'Right', 'mascot-core-elementor' )
						),
						'default' => 'owl-dots-center',
						'condition' => [
							'display_type' => array('carousel')
						]
					]
				);
				break;

			case '5':
				$control_object->add_control(
					$prefix . "carousel_autoplay",[
						'label' => esc_html__( "Autoplay", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SWITCHER,
						'default' => 'yes',
						'condition' => $dependency
					]
				);
				break;

			case '6':
				$control_object->add_control(
					$prefix . "carousel_loop", [
						'label' => esc_html__( "Loop", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SWITCHER,
						'default' => 'yes',
						'condition' => $dependency
					]
				);
				break;

			case '7':
				$control_object->add_control(
					$prefix . "animation_speed", [
						'label' => esc_html__( "Autoplay Interval Timeout", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						"description" => esc_html__( "Autoplay interval timeout in milliseconds. Default value is 6000", 'mascot-core-elementor' ),
						'condition' => $dependency
					]
				);
				break;

			case '8':
				$control_object->add_control(
					$prefix . "smart_speed", [
						'label' => esc_html__( "Smart Speed", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						"description" => esc_html__( "Autoplay Smart Speed in milliseconds. Default value is 300", 'mascot-core-elementor' ),
						'condition' => $dependency
					]
				);
				break;

			case '9':
				$control_object->add_control(
					$prefix . "margin", [
						'label' => esc_html__( "Margin", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						"description" => esc_html__( "Margin between two slides. Default 30", 'mascot-core-elementor' ),
						'condition' => $dependency
					]
				);
				break;

			case '10':
				$control_object->add_control(
					$prefix . "stagepadding", [
						'label' => esc_html__( "Stage Padding", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						"description" => esc_html__( "Stage padding option adds left and right padding style onto stage-wrapper. Example: 50", 'mascot-core-elementor' ),
						'condition' => $dependency
					]
				);
				break;

			case '11':
				$control_object->add_control(
					$prefix . "laptop", [
						'label' => esc_html__( "Responsive Slider Columns in Laptop / Small Desktop", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						"description" => esc_html__( "Number of Visible Sliding Items in Laptop or Small Desktop", 'mascot-core-elementor' ),
						'condition' => $dependency
					]
				);
				break;

			case '12':
				$control_object->add_control(
					$prefix . "tablet", [
						'label' => esc_html__( "Responsive Slider Columns in Tablet", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						'condition' => $dependency
					]
				);
				break;

			case '13':
				$control_object->add_control(
					$prefix . "center", [
						'label' => esc_html__( "Carousel Center Feature?", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SWITCHER,
						'default' => 'no',
						"description" => esc_html__( "This feature adds a class called 'center' into the middle image. Keep in mind that dots are not working here like a pagination", 'mascot-core-elementor' ),
						'condition' => $dependency
					]
				);
				break;

			case '14':
				$control_object->add_control(
					$prefix . "focused-center-image", [
						'label' => esc_html__( "Focused Center Image?", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SWITCHER,
						'default' => 'no',
						"description" => esc_html__( "Focus Center Image and Blur Other Images", 'mascot-core-elementor' ),
						'condition' => [
							'center' => array('yes')
						]
					]
				);
				break;

			case '15':
				$control_object->add_control(
					$prefix . "zoomin-center-image", [
						'label' => esc_html__( "ZoomIn Center Image?", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SWITCHER,
						'default' => 'no',
						'condition' => [
							'center' => array('yes')
						]
					]
				);
				break;

			default:
				# code...
				break;
		}

		return $array;
	}
}

if(!function_exists('mascot_core_novio_elementor_get_cat_filter_arraylist')) {
	/**
	 * Return Category Filter Array List
	 */
	function mascot_core_novio_elementor_get_cat_filter_arraylist( $control_object, $serial, $dependency = array() ) {
		$array = array();

		switch ( $serial ) {
			case '1':
				$control_object->add_control(
					"show_cat_filter", [
						'label' => esc_html__( "Show Category Filter?", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SWITCHER,
						'default' => 'no',
						'condition' => $dependency
					]
				);
				break;

			case '2':
				$control_object->add_control(
					'cat_filter_style', [
						'label' => esc_html__( "Filter Style", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'options' => [
							'filter-style-1'	=>	esc_html__( 'Style 1', 'mascot-core-elementor' ),
							'filter-style-2'	=>	esc_html__( 'Style 2', 'mascot-core-elementor' ),
							'filter-style-3'	=>	esc_html__( 'Style 3', 'mascot-core-elementor' ),
							'filter-style-4'	=>	esc_html__( 'Style 4', 'mascot-core-elementor' ),
							'filter-style-5'	=>	esc_html__( 'Style 5', 'mascot-core-elementor' ),
							'filter-style-6'	=>	esc_html__( 'Style 6', 'mascot-core-elementor' ),
							'filter-style-7'	=>	esc_html__( 'Style 7', 'mascot-core-elementor' ),
							'filter-style-8'	=>	esc_html__( 'Style 8', 'mascot-core-elementor' ),
							'filter-style-9'	=>	esc_html__( 'Style 9', 'mascot-core-elementor' ),
							'filter-style-10'	=>	esc_html__( 'Style 10', 'mascot-core-elementor' ),
							'filter-style-11'	=>	esc_html__( 'Style 11', 'mascot-core-elementor' ),
							'filter-style-12'	=>	esc_html__( 'Style 12', 'mascot-core-elementor' ),
							'filter-style-13'	=>	esc_html__( 'Style 13', 'mascot-core-elementor' ),
							'filter-style-14'	=>	esc_html__( 'Style 14', 'mascot-core-elementor' ),
							'filter-style-15'	=>	esc_html__( 'Style 15', 'mascot-core-elementor' ),
							'filter-style-16'	=>	esc_html__( 'Style 16', 'mascot-core-elementor' ),
							'filter-style-flat'	=>	esc_html__( 'Style flat', 'mascot-core-elementor' )
						],
						'default' => 'filter-style-3',
						'condition' => [
							'show_cat_filter' => array('yes')
						]
					]
				);
				break;

			case '3':
				$control_object->add_control(
					'cat_filter_alignment', [
						'label' => esc_html__( "Filter Alignment", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'options' => novio_mascot_redux_text_alignment_list(),
						'default' => 'filter-style-3',
						'condition' => [
							'show_cat_filter' => array('yes')
						]
					]
				);
				break;

			case '4':
				$control_object->add_control(
					'cat_filter_theme_colored', [
						'label' => esc_html__( "Filter Theme Colored", 'mascot-core-elementor' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'options' => [
							'cat-filter-default'	=>	esc_html__( 'Default', 'mascot-core-elementor' ),
							'cat-filter-theme-colored1'	=>	esc_html__( 'Theme Color 1', 'mascot-core-elementor' ),
							'cat-filter-theme-colored2'	=>	esc_html__( 'Theme Color 2', 'mascot-core-elementor' )
						],
						'default' => 'cat-filter-default',
						'condition' => [
							'show_cat_filter' => array('yes')
						]
					]
				);
				break;

			default:
				# code...
				break;
		}

		return $array;
	}
}

if (!function_exists('mascot_core_novio_elementor_shortcode_get_blog_post_format')) {
  /**
   * Return Shortcode Blog Post Format HTML
   */
  function mascot_core_novio_elementor_shortcode_get_blog_post_format( $post_format = '', $params = array() ) {

    $format = $post_format ? : 'standard';
    $params['post_format'] = $format;

    //Produce HTML version by using the parameters (filename, variation, folder name, parameters)
    $html = mascot_core_novio_elementor_get_shortcode_template_part( 'post-format', $format, 'blog/tpl/post-format', $params, true );
    return $html;
  }
}

if(!function_exists('mascot_core_novio_elementor_get_animation_type')) {
	/**
	 * Return animation type
	 */
	function mascot_core_novio_elementor_get_animation_type() {
		$array = array(
			''  =>  esc_html__( 'None', 'mascot-core-elementor' ),
			'tm-animation-floating'  =>  esc_html__( 'Floating Animation', 'mascot-core-elementor' ),
			'tm-animation-slide-horizontal'  =>  esc_html__( 'Horizontal Slide Animation', 'mascot-core-elementor' ),
			'tm-animation-scaling'  =>  esc_html__( 'Scaling Animation', 'mascot-core-elementor' ),
			'tm-animation-flicker'  =>  esc_html__( 'Flicker Animation', 'mascot-core-elementor' ),
			'tm-animation-spin'  =>  esc_html__( 'Spin Animation', 'mascot-core-elementor' ),

			'tm-animation-floating'	=>	esc_html__( 'Floating Animation', 'mascot-core-elementor' ),
			'tm-animation-slide-horizontal'	=>	esc_html__( 'Horizontal Slide Animation', 'mascot-core-elementor' ),
			'tm-animation-scaling'	=>	esc_html__( 'Scaling Animation', 'mascot-core-elementor' ),

			'tm-animation-flicker'	=>	esc_html__( 'Flicker Animation', 'mascot-core-elementor' ),
			'tm-animation-spin'	=>	esc_html__( 'Spin Animation', 'mascot-core-elementor' ),
			'tm-animation-rotated-half'	=>	esc_html__( 'Rotated Half Animation', 'mascot-core-elementor' ),
			'tm-animation-jump'	=>	esc_html__( 'Jump Animation', 'mascot-core-elementor' ),

			'tm-animation-run'	=>	esc_html__( 'Run Animation', 'mascot-core-elementor' ),
			'tm-animation-scale-right'	=>	esc_html__( 'Scale Right Animation', 'mascot-core-elementor' ),

			'tm-animation-random-animation1'	=>	esc_html__( 'Random Animation 1', 'mascot-core-elementor' ),
			'tm-animation-random-animation2'	=>	esc_html__( 'Random Animation 2', 'mascot-core-elementor' ),
			'tm-animation-random-animation3'	=>	esc_html__( 'Random Animation 3', 'mascot-core-elementor' ),
			'tm-animation-random-animation4'	=>	esc_html__( 'Random Animation 4', 'mascot-core-elementor' ),
			'tm-animation-random-animation5'	=>	esc_html__( 'Random Animation 5', 'mascot-core-elementor' )
		);
		return $array;
	}
}