<?php
namespace MascotCoreNovioElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Animated_Layers extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tm-ele-animated-layers';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Animated Layers', 'mascot-core-elementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tm' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'mascot-core-hellojs' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

			$this->start_controls_section(
					'general',
					[
							'label' => esc_html__( 'General', 'mascot-core-elementor' ),
							'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
			);
			$this->add_control(
				'custom_css_class',
				[
					'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			
			$repeater = new \Elementor\Repeater();
			$repeater->add_control(
				'display_type', [
					'label' => esc_html__( "Layer Type", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => [
						'layer-image' =>  esc_html__( 'Image Layer', 'mascot-core-elementor' ),
						'layer-text'  =>  esc_html__( 'Text Layer', 'mascot-core-elementor' ),
						'layer-play-btn'  =>  esc_html__( 'Video Play Button', 'mascot-core-elementor' ),
						'layer-animated-icon'  =>  esc_html__( 'Animated Icon', 'mascot-core-elementor' ),
					],
					'default' => 'layer-image'
				]
			);


			$repeater->add_control(
				'image_animation_effect', [
					'label' => esc_html__( "Layer Animation Effect", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => mascot_core_novio_tm_custom_animation_class_list(),
				]
			);



			//image
			$repeater->add_control(
				'image', [
					'label' => esc_html__( "Image", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'condition' => [
						'display_type' => array('layer-image')
					]
				]
			);
			$repeater->add_control(
				'image_size', [
					'label' => esc_html__( "Image Size", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => mascot_core_novio_elementor_get_available_image_sizes(),
					'default' => 'full',
					'condition' => [
						'display_type' => array('layer-image')
					]
				]
			);
			$repeater->add_control(
				'main_parent_wrapper_custom_css_class',
				[
					'label' => esc_html__( "Main Parent Wrapper Custom CSS class", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					"description" => esc_html__( "To style particular content element.", 'mascot-core-elementor' ),
					'condition' => [
						'display_type' => array('layer-image')
					]
				]
			);
			$repeater->add_control(
				'main_parent_wrapper_inline_style',
				[
					'label' => esc_html__( "Main Parent Wrapper Custom Inline CSS", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					"description" => esc_html__( "Example: top: 12px; left: 100px;", 'mascot-core-elementor' ),
					'condition' => [
						'display_type' => array('layer-image')
					]
				]
			);
			$repeater->add_control(
				'image_parent_custom_css_class',
				[
					'label' => esc_html__( "Image Parent Custom CSS class", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					"description" => esc_html__( "To style particular content element.", 'mascot-core-elementor' ),
					'condition' => [
						'display_type' => array('layer-image')
					]
				]
			);
			$repeater->add_control(
				'image_custom_css_class',
				[
					'label' => esc_html__( "Image Custom CSS class", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					"description" => esc_html__( "To style particular content element.", 'mascot-core-elementor' ),
					'condition' => [
						'display_type' => array('layer-image')
					]
				]
			);
			$repeater->add_control(
				'make_item_fullwidth', [
					'label' => esc_html__( "Make this Item Fullwidth?", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'default' => 'yes',
					'condition' => [
						'display_type' => array('layer-image')
					]
				]
			);







			//text
			$repeater->add_control(
				'image_wrapper_custom_css_class',
				[
					'label' => esc_html__( "Parent Wrapper Custom CSS class", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					"description" => esc_html__( "To style particular content element.", 'mascot-core-elementor' ),
					'condition' => [
						'display_type' => array('layer-text')
					]
				]
			);
			$repeater->add_control(
				'image_wrapper_inline_style',
				[
					'label' => esc_html__( "Parent Wrapper Custom Inline CSS", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					"description" => esc_html__( "Example: top: 12px; left: 100px;", 'mascot-core-elementor' ),
					'condition' => [
						'display_type' => array('layer-text')
					]
				]
			);


			//play btn
			$repeater->add_control(
				'video_url', [
					'label' => esc_html__( "Youtube Video URL", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => 'https://www.youtube.com/watch?v=Tb1HsAGy-ls',
					'condition' => [
						'display_type' => array('layer-play-btn')
					]
				]
			);


			//animated icon
			$repeater->add_control(
				'animated_icon', [
					'label' => esc_html__( "Icon", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'condition' => [
						'display_type' => array('layer-animated-icon')
					]
				]
			);
			$repeater->add_control(
				'animated_icon_hover', [
					'label' => esc_html__( "Hover Icon", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'condition' => [
						'display_type' => array('layer-animated-icon')
					]
				]
			);














			//commom
			$repeater->add_control(
				'padding',
				[
					'label' => esc_html__( "Padding", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'margin',
				[
					'label' => esc_html__( "Margin", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'pos_top',
				[
					'label' => esc_html__( "Top", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'pos_right',
				[
					'label' => esc_html__( "Right", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'pos_bottom',
				[
					'label' => esc_html__( "Bottom", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'pos_left',
				[
					'label' => esc_html__( "Left", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'width',
				[
					'label' => esc_html__( "Width", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$repeater->add_control(
				'height',
				[
					'label' => esc_html__( "Height", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);




			$repeater->add_control(
				'bg_theme_colored',
				[
					'label' => esc_html__( "Background Theme Colored", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => novio_mascot_theme_color_list(),
					'default' => '',
					'condition' => [
						'display_type' => array('layer-text')
					]
				]
			);
			$repeater->add_control(
				'custom_bg_color',
				[
					'label' => esc_html__( "Custom Background Color", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'condition' => [
						'display_type' => array('layer-text')
					]
				]
			);

			$repeater->add_control(
				'add_box_shadow', [
					'label' => esc_html__( "Add Box Shadow?", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'default' => 'yes',
				]
			);


			$repeater->add_control(
				'content',
				[
					'label' => esc_html__( "Paragraph", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::WYSIWYG,
					'default' => esc_html__( "Write a short description.", 'mascot-core-elementor' ),
					'condition' => [
						'display_type' => array('layer-text')
					]
				]
			);

			$this->add_control(
					'animated_layer_images',
					[
							'label' => esc_html__( "Animated Layer Images", 'mascot-core-elementor' ),
							'type' => \Elementor\Controls_Manager::REPEATER,
							'fields' => $repeater->get_controls(),
							//'title_field' => esc_html__('Each Animated Layer Image'),
							'title_field' => '{{{ display_type }}}',
					]
			);

			$this->end_controls_section();

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$html = '';
		//classes
		$classes = array();
		$classes[] = 'tm-sc tm-sc-animated-layer-advanced';
		$classes[] = $settings['custom_css_class'];
		$settings['classes'] = $classes;
	?>
		<div class="<?php echo esc_attr(implode(' ', $classes)); ?>">
			<div class="animated-layer-advanced-inner clearfix">
	<?php
		if ( $settings['animated_layer_images'] ) { 
			foreach (  $settings['animated_layer_images'] as $item ) {
    		$item['wrapper_inline_css'] = mascot_core_novio_elementor_animated_layer_wrapper_inline_css( $item );
				//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
				$html .= mascot_core_novio_elementor_get_shortcode_template_part( $item['display_type'], null, 'animated-layers/tpl', $item, true );
			}
		} 
		echo $html;
	?>
			</div>
		</div>
	<?php
	}
}

if(!function_exists('mascot_core_novio_elementor_animated_layer_wrapper_inline_css')) {
	/**
	 * Get Wrapper Styles
	 */
	function mascot_core_novio_elementor_animated_layer_wrapper_inline_css( $params ) {
		$css_array = array();

		if( $params['padding'] != '' ) {
			$css_array[] = 'padding: '.$params['padding'];
		}
		if( $params['margin'] != '' ) {
			$css_array[] = 'margin: '.$params['margin'];
		}
		if( $params['pos_top'] != '' ) {
			$css_array[] = 'top: '.$params['pos_top'];
		}
		if( $params['pos_right'] != '' ) {
			$css_array[] = 'right: '.$params['pos_right'];
		}
		if( $params['pos_bottom'] != '' ) {
			$css_array[] = 'bottom: '.$params['pos_bottom'];
		}
		if( $params['pos_left'] != '' ) {
			$css_array[] = 'left: '.$params['pos_left'];
		}
		if( $params['width'] != '' ) {
			$css_array[] = 'width: '.$params['width'];
		}
		if( $params['height'] != '' ) {
			$css_array[] = 'height: '.$params['height'];
		}
		if( $params['custom_bg_color'] != '' ) {
			$css_array[] = 'background-color: '.$params['custom_bg_color'];
		}
		return implode( '; ', $css_array );
	}
}