<?php
namespace MascotCoreNovioElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Call_To_Action extends Widget_Base {

  /**
   * Retrieve the widget name.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'tm-ele-call-to-action';
  }

  /**
   * Retrieve the widget title.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return __( 'Call To Action', 'mascot-core-elementor' );
  }

  /**
   * Retrieve the widget icon.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-posts-ticker';
  }

  /**
   * Retrieve the list of categories the widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * Note that currently Elementor supports only one category.
   * When multiple categories passed, Elementor uses the first one.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'tm' ];
  }

  /**
   * Retrieve the list of scripts the widget depended on.
   *
   * Used to set scripts dependencies required to run the widget.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget scripts dependencies.
   */
  public function get_script_depends() {
    return [ 'mascot-core-hellojs' ];
  }

  /**
   * Register the widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function register_controls() {

      $this->start_controls_section(
          'general',
          [
              'label' => esc_html__( 'General', 'mascot-core-elementor' ),
              'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      $this->add_control(
          'custom_css_class',
          [
              'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'content_in_grid',
          [
              'label' => esc_html__( "Content in grid?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
              'default' => 'no',
          ]
      );
      $this->add_control(
          'grid_size',
          [
              'label' => esc_html__( "Grid size", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'description' => esc_html__( "Choose grid size", 'mascot-core-elementor' ),
              'options' => [
                  '102' => esc_html__( '10:2', 'mascot-core-elementor' ),
                  '93' => esc_html__( '9:3', 'mascot-core-elementor' ),
                  '66' => esc_html__( '6:6', 'mascot-core-elementor' ),
                  '66' => esc_html__( '8:4', 'mascot-core-elementor' ),
              ],
              'default' => '102',
              'condition' => [
                  'content_in_grid' => array('yes')
              ]
          ]
      );
      $this->add_control(
          'visual_style',
          [
              'label' => esc_html__( "Visual Style", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                  'default' => esc_html__( 'Default', 'mascot-core-elementor' ),
                  'with-icons' => esc_html__( 'With Icon', 'mascot-core-elementor' ),
                  'with-buttons' => esc_html__( 'With Two Buttons Below', 'mascot-core-elementor' ),
              ],
              'default' => 'default',
          ]
      );
      $this->add_control(
          'show_button',
          [
              'label' => esc_html__( "Show Button?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
              'default' => 'yes',
              'condition' => [
                  'visual_style' => array('default')
              ]
          ]
      );
      $this->add_control(
        'content',
        [
          'label' => esc_html__( "Content", 'mascot-core-elementor' ),
          'type' => \Elementor\Controls_Manager::WYSIWYG,
          'default' => esc_html__( "Default text for Call to action. Lorem ipsum dolor sit amet, consectetur adipisicing elit.", 'mascot-core-elementor' )
        ]
      );
      $this->end_controls_section();




      $this->start_controls_section(
          'button_options',
          [
              'label' => esc_html__( 'Button Options', 'mascot-core-elementor' ),
              'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
              'condition' => [
                  'show_button' => array('yes'),
              ]
          ]
      );
      $this->add_control(
          'button_0_text',
          [
              'label' => esc_html__( "Button Text", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'default' => '',
              'description' => esc_html__( 'Default text is "Read More', 'mascot-core-elementor' ),
          ]
      );
      $this->add_control(
          'button_0_link',
          [
              'label' => esc_html__( "Button Link", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'default' => '',
              'description' => esc_html__( 'Link must starts with http:// or https://', 'mascot-core-elementor' ),
          ]
      );
      $this->add_control(
          'button_0_target',
          [
              'label' => esc_html__( "Button Target", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                  '_self' => esc_html__( 'Self', 'mascot-core-elementor' ),
                  '_blank' => esc_html__( 'New Tab (Blank)', 'mascot-core-elementor' ),
              ],
              'default' => 'final-countdown-advanced-coupon'
          ]
      );
      $this->end_controls_section();




      $this->start_controls_section(
          'button_design_options',
          [
              'label' => esc_html__( 'Button Design Options', 'mascot-core-elementor' ),
              'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
              'condition' => [
                  'show_button' => array('yes')
              ]
          ]
      );
      $this->add_control(
          'button_0_design_style',
          [
              'label' => esc_html__( "Button Design Style", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                  'btn-default' => esc_html__( 'Button Default', 'mascot-core-elementor' ),
                  'btn-border' => esc_html__( 'Button Border', 'mascot-core-elementor' ),
                  'btn-dark' => esc_html__( 'Button Dark', 'mascot-core-elementor' ),
                  'btn-gray' => esc_html__( 'Button Gray', 'mascot-core-elementor' ),
              ],
              'default' => 'btn-default'
          ]
      );
      $this->add_control(
          'button_0_size',
          [
              'label' => esc_html__( "Button Size", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                  'default' => esc_html__( 'Default', 'mascot-core-elementor' ),
                  'btn-xs' => esc_html__( 'Extra Small', 'mascot-core-elementor' ),
                  'btn-sm' => esc_html__( 'Small', 'mascot-core-elementor' ),
                  'btn-lg' => esc_html__( 'Large', 'mascot-core-elementor' ),
                  'btn-xl' => esc_html__( 'Extra Large', 'mascot-core-elementor' ),
              ],
              'default' => 'default'
          ]
      );
      $this->add_control(
          'button_0_btn_theme_colored',
          [
              'label' => esc_html__( "Make Button Theme Colored?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => '',
              'default' => ''
          ]
      );
      $this->add_control(
          'button_0_position',
          [
              'label' => esc_html__( "Button Position", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                  'text-right' => esc_html__( 'Right', 'mascot-core-elementor' ),
                  'text-center' => esc_html__( 'Center', 'mascot-core-elementor' ),
                  'text-left' => esc_html__( 'Left', 'mascot-core-elementor' ),
              ],
              'default' => ''
          ]
      );
      $this->end_controls_section();




      $this->start_controls_section(
          'icon_options',
          [
              'label' => esc_html__( 'Icon Options', 'mascot-core-elementor' ),
              'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
              'condition' => [
                  'show_button' => array('yes')
              ]
          ]
      );
      $this->add_control(
          'button_0_design_style',
          [
              'label' => esc_html__( "Button Design Style", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                  'btn-default' => esc_html__( 'Button Default', 'mascot-core-elementor' ),
                  'btn-border' => esc_html__( 'Button Border', 'mascot-core-elementor' ),
                  'btn-dark' => esc_html__( 'Button Dark', 'mascot-core-elementor' ),
                  'btn-gray' => esc_html__( 'Button Gray', 'mascot-core-elementor' ),
              ],
              'default' => 'btn-default'
          ]
      );
      $this->add_control(
          'button_0_size',
          [
              'label' => esc_html__( "Button Size", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                  'default' => esc_html__( 'Default', 'mascot-core-elementor' ),
                  'btn-xs' => esc_html__( 'Extra Small', 'mascot-core-elementor' ),
                  'btn-sm' => esc_html__( 'Small', 'mascot-core-elementor' ),
                  'btn-lg' => esc_html__( 'Large', 'mascot-core-elementor' ),
                  'btn-xl' => esc_html__( 'Extra Large', 'mascot-core-elementor' ),
              ],
              'default' => 'default'
          ]
      );
      $this->add_control(
          'button_0_btn_theme_colored',
          [
              'label' => esc_html__( "Make Button Theme Colored?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => '',
              'default' => ''
          ]
      );
      $this->add_control(
          'button_0_position',
          [
              'label' => esc_html__( "Button Position", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                  'text-right' => esc_html__( 'Right', 'mascot-core-elementor' ),
                  'text-center' => esc_html__( 'Center', 'mascot-core-elementor' ),
                  'text-left' => esc_html__( 'Left', 'mascot-core-elementor' ),
              ],
              'default' => ''
          ]
      );
      $this->end_controls_section();


  }

  /**
   * Render the widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function render() {
    $settings = $this->get_settings_for_display();

    wp_register_script( 'jquery-countdown', MASCOT_CORE_TEMPLATE_URI . '/assets/js/plugins/jquery.countdown.min.js', array('jquery'), false, true );
    wp_register_script( 'jquery-final-countdown', MASCOT_CORE_TEMPLATE_URI . '/assets/js/plugins/jquery.final-countdown.min.js', array('jquery'), false, true );
    wp_enqueue_script( 'jquery-countdown' );
    wp_enqueue_script( 'jquery-final-countdown' );

    if( $settings['design_style'] == 'final-countdown-modern-circular' ) {
      wp_enqueue_script( 'kinetic' );
    }

    //classes
    $classes = array();
    $classes[] = $settings['custom_css_class'];
    $settings['classes'] = $classes;

    //Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
    $html = mascot_core_novio_elementor_get_shortcode_template_part( 'countdown-timer-' . $settings['design_style'], null, 'countdown-timer/tpl', $settings, true );

    echo $html;
  }
}
