<?php
namespace MascotCoreNovioElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Pie_Chart extends Widget_Base {

  /**
   * Retrieve the widget name.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'tm-ele-pie-chart';
  }

  /**
   * Retrieve the widget title.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return __( 'Pie Chart', 'mascot-core-elementor' );
  }

  /**
   * Retrieve the widget icon.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-posts-ticker';
  }

  /**
   * Retrieve the list of categories the widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * Note that currently Elementor supports only one category.
   * When multiple categories passed, Elementor uses the first one.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'tm' ];
  }

  /**
   * Retrieve the list of scripts the widget depended on.
   *
   * Used to set scripts dependencies required to run the widget.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget scripts dependencies.
   */
  public function get_script_depends() {
    return [ 'mascot-core-hellojs' ];
  }

  /**
   * Register the widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function register_controls() {

      $this->start_controls_section(
          'general',
          [
              'label' => esc_html__( 'General', 'mascot-core-elementor' ),
              'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      $this->add_control(
          'custom_css_class',
          [
              'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'percent',
          [
              'label' => esc_html__( "Percentage Value", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'description' => esc_html__( "Add a Percentage Value. Maximum 100. Default: 85", 'mascot-core-elementor' ),
              'default' => '85'
          ]
      );
      $this->add_control(
          'barcolor',
          [
              'label' => esc_html__( "Bar Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
              'description' => esc_html__( "The color of the curcular bar. Leave empty for default value", 'mascot-core-elementor' ),
              'default' => '#ef1e25'
          ]
      );
      $this->add_control(
          'trackcolor',
          [
              'label' => esc_html__( "Track Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
              'description' => esc_html__( "The color of the track, or false to disable rendering. Leave empty for default value", 'mascot-core-elementor' ),
              'default' => '#f2f2f2'
          ]
      );
      $this->add_control(
          'scalecolor',
          [
              'label' => esc_html__( "Scale  Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
              'description' => esc_html__( "The color of the scale lines, false to disable rendering. Leave empty for default value", 'mascot-core-elementor' ),
              'default' => '#dfe0e0'
          ]
      );
      $this->add_control(
          'scalelength',
          [
              'label' => esc_html__( "Scale Length", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'description' => esc_html__( "Length of the scale lines (reduces the radius of the chart). Default: 5", 'mascot-core-elementor' ),
              'default' => '5'
          ]
      );
      $this->add_control(
          'linecap',
          [
              'label' => esc_html__( "Line Cap", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                'square' => esc_html__( 'Square', 'mascot-core-elementor' ),
                'butt' => esc_html__( 'Butt', 'mascot-core-elementor' ),
                'round' => esc_html__( 'Round', 'mascot-core-elementor' ),
              ],
              'default' => 'square'
          ]
      );
      $this->add_control(
          'size',
          [
              'label' => esc_html__( "Size", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'description' => esc_html__( "Size of the pie chart in px. It will always be a square. Default: 110", 'mascot-core-elementor' ),
              'default' => '110'
          ]
      );
      $this->add_control(
          'title',
          [
              'label' => esc_html__( "Title", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'default' => ''
          ]
      );
      $this->add_control(
          'title_tag',
          [
              'label' => esc_html__( "Title Tag", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'description' => esc_html__( "Size of the pie chart in px. It will always be a square. Default: 110", 'mascot-core-elementor' ),
              'options' => novio_mascot_heading_tag_list(),
              'default' => 'h3'
          ]
      );
      $this->add_control(
          'title_color',
          [
              'label' => esc_html__( "Title Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
          ]
      );
      $this->add_control(
          'text',
          [
              'label' => esc_html__( "Text", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXTAREA,
              'description' => esc_html__( "Size of the pie chart in px. It will always be a square. Default: 110", 'mascot-core-elementor' ),
          ]
      );
      $this->add_control(
          'text_color',
          [
              'label' => esc_html__( "Text Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
          ]
      );

      $this->end_controls_section();
  }

  /**
   * Render the widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function render() {
    $settings = $this->get_settings_for_display();

    //classes
    $classes = array();
    $classes[] = $settings['custom_css_class'];
    $settings['classes'] = $classes;

    wp_register_script( 'jquery-easypiechart', MASCOT_CORE_TEMPLATE_URI . '/assets/js/plugins/jquery.easypiechart.min.js', array('jquery'), false, true );
    wp_enqueue_script( 'jquery-easypiechart' );

    $settings['box_inline_css'] = novio_mascot_get_inline_css( novio_mascot_sc_pie_chart_box_css( $settings ) );

    $settings['title_inline_css'] = '';
    if( $settings['title_color'] ) {
      $settings['title_inline_css'] = novio_mascot_get_inline_css( 'color: '. $settings['title_color'] );
    }

    $settings['text_inline_css'] = '';
    if( $settings['text_color'] ) {
      $settings['text_inline_css'] = novio_mascot_get_inline_css( 'color: '. $settings['text_color'] );
    }

    //Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
    $html = mascot_core_novio_elementor_get_shortcode_template_part( 'pie-chart', null, 'pie-chart/tpl', $settings, true );

    echo $html;
  }
}
if(!function_exists('novio_mascot_sc_pie_chart_box_css')) {
  /**
   * Get Parent Box Styles
   */
  function novio_mascot_sc_pie_chart_box_css( $settings ) {
    $css_array = array();

    if( $settings['size'] != '' ) {
      $css_array[] = 'width: '.novio_mascot_if_numeric_add_suffix($settings['size'], 'px');
      $css_array[] = 'height: '.novio_mascot_if_numeric_add_suffix($settings['size'], 'px');
      $css_array[] = 'line-height: '.novio_mascot_if_numeric_add_suffix($settings['size'], 'px');
    }
    return implode( '; ', $css_array );
  }
}