<?php
namespace MascotCoreNovioElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Progress_Bar extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tm-ele-progress-bar';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Progress Bar', 'mascot-core-elementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tm' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'mascot-core-hellojs' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
  protected function register_controls() {

      $this->start_controls_section(
          'general',
          [
              'label' => esc_html__( 'General', 'mascot-core-elementor' ),
              'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      $this->add_control(
          'custom_css_class',
          [
              'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'design_style',
          [
              'label' => esc_html__( "Design Style", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::MEDIA,
              'options' => [
                  'default' => esc_html__( 'Default', 'mascot-core-elementor' ),
                  'floating-percent' => esc_html__( 'Floating Percent', 'mascot-core-elementor' ),
                  'fixed-right-percent' => esc_html__( 'Fixed Right Percent', 'mascot-core-elementor' ),
              ],
              'default' => 'default'
          ]
      );
      $this->end_controls_section();






      $this->start_controls_section(
          'title_options',
          [
              'label' => esc_html__( 'Title Options', 'mascot-core-elementor' ),
              'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      $this->add_control(
          'title',
          [
              'label' => esc_html__( "Title", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              "description" => esc_html__( "Add your Progress/Skill Title Text. Default: WordPress", 'mascot-core-elementor' ),
              'default' => esc_html__( "WordPress", 'mascot-core-elementor' )
          ]
      );
      $this->add_control(
          'title_tag',
          [
              'label' => esc_html__( "Title Tag", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => novio_mascot_heading_tag_list(),
              'default' => 'h3'
          ]
      );
      $this->end_controls_section();






      $this->start_controls_section(
          'other_options',
          [
              'label' => esc_html__( 'Other Options', 'mascot-core-elementor' ),
              'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      $this->add_control(
          'percentage_value',
          [
              'label' => esc_html__( "Percentage Value", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              "description" => esc_html__( "Add a Percentage Value. Maximum 100. Default: 85", 'mascot-core-elementor' ),
              'default' => esc_html__( "85", 'mascot-core-elementor' )
          ]
      );
      $this->add_control(
          'unit_symbol_left',
          [
              'label' => esc_html__( "Unit Symbol Left", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              "description" => esc_html__( "Add an Unit Symbol to the Left of Percent Value", 'mascot-core-elementor' ),
          ]
      );
      $this->add_control(
          'unit_symbol_right',
          [
              'label' => esc_html__( "Unit Symbol Right", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              "description" => esc_html__( "Add an Unit Symbol to the Right of Percent Value", 'mascot-core-elementor' ),
          ]
      );
      $this->add_control(
          'progress_bar_height',
          [
              'label' => esc_html__( "Progress Bar Height", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'progress_color',
          [
              'label' => esc_html__( "Progress Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
              "description" => esc_html__( "Pick a color for progress bar. Leave empty for default value", 'mascot-core-elementor' ),
          ]
      );
      $this->add_control(
          'background_color',
          [
              'label' => esc_html__( "Background Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
              "description" => esc_html__( "Pick a color for the background of progress bar. Leave empty for default value", 'mascot-core-elementor' ),
          ]
      );
      $this->end_controls_section();





      // Add predefined developer tab content for each shortcode element
      $this->start_controls_section(
          'developer_tools',
          [
              'label' => esc_html__( 'Developer Tools', 'mascot-core-elementor' ),
              'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );

      $this->add_control(
          'shortcode_snippet',
          [
              'label'   => esc_html__( 'Show Shortcode Snippet', 'mascot-core-elementor' ),
              'type'    => \Elementor\Controls_Manager::SELECT,
              'default' => 'no',
              'options' => array(
                  'no'  => esc_html__( 'No', 'mascot-core-elementor' ),
                  'yes' => esc_html__( 'Yes', 'mascot-core-elementor' ),
              ),
          ]
      );


      $this->end_controls_section();
  }

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();


    if( $settings['background_color'] ) {
      $settings['progress_inline_css'] = novio_mascot_get_inline_css( 'background-color: '. $settings['background_color'] );
    } else {
      $settings['progress_inline_css'] = '';
    }
    $settings['progress_color'] = novio_mascot_get_inline_attributes( $settings['progress_color'], 'data-barcolor' );

    //classes
    $classes = array();
    $classes[] = 'progress-bar-' . $settings['design_style'];
    $classes[] = $settings['custom_css_class'];
    $settings['classes'] = $classes;

    wp_register_script( 'jquery-countto', MASCOT_CORE_TEMPLATE_URI . '/assets/js/plugins/jquery.countto.js', array('jquery'), false, true );
    wp_enqueue_script( 'jquery-countto' );


		$html = mascot_core_novio_elementor_get_shortcode_template_part( 'progress-bar-' . $settings['design_style'], null, 'progress-bar/tpl', $settings, true );

		echo $html;
	}
}
